==> wawa-service-api-0.0.19-20180108.055856-20-sources.jar: cn/com/wawa/service/api/dto/BannerDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;
import java.util.Date;

public class BannerDto implements Serializable {
    private static final long serialVersionUID = -3507612119876277167L;

    private Long id;

    private String image;

    private String url;

    private String bannerName;

    private Long payload;

    private Date openTime;

    private Date closeTime;

    private Integer bannerStatus;

    private Date gmtCreate;

    private Date gmtModified;

    private Long activityType;

    private Long activityId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getBannerName() {
        return bannerName;
    }

    public void setBannerName(String bannerName) {
        this.bannerName = bannerName;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Date getOpenTime() {
        return openTime;
    }

    public void setOpenTime(Date openTime) {
        this.openTime = openTime;
    }

    public Date getCloseTime() {
        return closeTime;
    }

    public void setCloseTime(Date closeTime) {
        this.closeTime = closeTime;
    }

    public Integer getBannerStatus() {
        return bannerStatus;
    }

    public void setBannerStatus(Integer bannerStatus) {
        this.bannerStatus = bannerStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getActivityType() {
        return activityType;
    }

    public void setActivityType(Long activityType) {
        this.activityType = activityType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }
}

==> wawa-service-api-0.0.20-20180116.071249-8-sources.jar: cn/com/wawa/service/api/dto/BannerDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;
import java.util.Date;

public class BannerDto implements Serializable {
    private static final long serialVersionUID = -3507612119876277167L;

    private Long id;

    private String image;

    private String url;

    private String bannerName;

    private Long payload;

    private Date openTime;

    private Date closeTime;

    private Integer bannerStatus;

    private Date gmtCreate;

    private Date gmtModified;

    private Long activityType;

    private Long activityId;

    private Integer clientType;

    private Long minVersionCode;

    private Long maxVersionCode;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getBannerName() {
        return bannerName;
    }

    public void setBannerName(String bannerName) {
        this.bannerName = bannerName;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Date getOpenTime() {
        return openTime;
    }

    public void setOpenTime(Date openTime) {
        this.openTime = openTime;
    }

    public Date getCloseTime() {
        return closeTime;
    }

    public void setCloseTime(Date closeTime) {
        this.closeTime = closeTime;
    }

    public Integer getBannerStatus() {
        return bannerStatus;
    }

    public void setBannerStatus(Integer bannerStatus) {
        this.bannerStatus = bannerStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getActivityType() {
        return activityType;
    }

    public void setActivityType(Long activityType) {
        this.activityType = activityType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }

    public Long getMinVersionCode() {
        return minVersionCode;
    }

    public void setMinVersionCode(Long minVersionCode) {
        this.minVersionCode = minVersionCode;
    }

    public Long getMaxVersionCode() {
        return maxVersionCode;
    }

    public void setMaxVersionCode(Long maxVersionCode) {
        this.maxVersionCode = maxVersionCode;
    }
}
